searchData={"items":[{"type":"module","title":"ErrorTrackerNotifier","doc":"Attaches to ErrorTracker telemetry events and sends notifications for new errors.\n\nIncludes throttling to limit notification frequency for repeated errors.","ref":"ErrorTrackerNotifier.html"},{"type":"module","title":"Configuration - ErrorTrackerNotifier","doc":"Configure in your config.exs:\n\n```elixir\n# For email notifications\nconfig :error_tracker_notifier,\n  notification_type: :email,\n  from_email: \"support@example.com\",\n  to_email: \"support@example.com\",\n  mailer: MyApp.Mailer,\n  throttle_seconds: 10  # Optional: Throttle time between notifications (default: 10 seconds)\n\n# For Discord webhook notifications\nconfig :error_tracker_notifier,\n  notification_type: :discord,\n  webhook_url: \"https://discord.com/api/webhooks/your-webhook-url\",\n  throttle_seconds: 30  # Optional: Throttle time between notifications\n\n# For both email and Discord notifications\nconfig :error_tracker_notifier,\n  notification_type: [:email, :discord],  # Can be a single atom or a list\n  from_email: \"support@example.com\",\n  to_email: \"support@example.com\",\n  mailer: MyApp.Mailer,\n  webhook_url: \"https://discord.com/api/webhooks/your-webhook-url\",\n  throttle_seconds: 60  # Optional: Throttle time between notifications\n```","ref":"ErrorTrackerNotifier.html#module-configuration"},{"type":"module","title":"Setup - ErrorTrackerNotifier","doc":"Add to your application.ex:\n\n```elixir\ndef start(_type, _args) do\n  children = [\n    # ...other children\n    {ErrorTrackerNotifier, []}\n  ]\n\n  # Start the application supervisor\n  Supervisor.start_link(children, strategy: :one_for_one, name: MyApp.Supervisor)\nend\n```","ref":"ErrorTrackerNotifier.html#module-setup"},{"type":"function","title":"ErrorTrackerNotifier.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ErrorTrackerNotifier.html#child_spec/1"},{"type":"function","title":"ErrorTrackerNotifier.get_app_name/0","doc":"","ref":"ErrorTrackerNotifier.html#get_app_name/0"},{"type":"function","title":"ErrorTrackerNotifier.get_config/2","doc":"","ref":"ErrorTrackerNotifier.html#get_config/2"},{"type":"function","title":"ErrorTrackerNotifier.send_occurrence_notification/2","doc":"Send a notification for a new error occurrence.","ref":"ErrorTrackerNotifier.html#send_occurrence_notification/2"},{"type":"function","title":"ErrorTrackerNotifier.setup/0","doc":"Attach to ErrorTracker telemetry events.\nAutomatically called when the GenServer starts.\n\nYou can also call this function manually if you need to reattach telemetry events\nor if you're starting the process in a different way.","ref":"ErrorTrackerNotifier.html#setup/0"},{"type":"function","title":"ErrorTrackerNotifier.setup_telemetry/0","doc":"Setup telemetry handlers directly without requiring the GenServer to be running.\nThis can be used in applications where you want to handle telemetry events but\ndon't want to start the GenServer process.\n\nReturns :ok on success, or :error on failure.","ref":"ErrorTrackerNotifier.html#setup_telemetry/0"},{"type":"function","title":"ErrorTrackerNotifier.start_link/1","doc":"Starts the ErrorTrackerNotifier process.\n\nIf the process is already started, returns {:error, {:already_started, pid}}.\nThis is the expected behavior when started by a supervisor.","ref":"ErrorTrackerNotifier.html#start_link/1"},{"type":"module","title":"ErrorTrackerNotifier.Application","doc":"The application module for ErrorTrackerNotifier.\n\nStarts the ErrorTrackerNotifier GenServer which handles throttling notifications.","ref":"ErrorTrackerNotifier.Application.html"},{"type":"module","title":"ErrorTrackerNotifier.Discord","doc":"Handles sending error notifications to Discord via webhooks.","ref":"ErrorTrackerNotifier.Discord.html"},{"type":"function","title":"ErrorTrackerNotifier.Discord.send_occurrence_notification/3","doc":"Send a Discord webhook notification for a new error occurrence.\nThe header may include error count information if throttling has occurred.","ref":"ErrorTrackerNotifier.Discord.html#send_occurrence_notification/3"},{"type":"module","title":"ErrorTrackerNotifier.Email","doc":"Handles the generation and sending of error notification emails.","ref":"ErrorTrackerNotifier.Email.html"},{"type":"function","title":"ErrorTrackerNotifier.Email.send_occurrence_notification/3","doc":"Send an email notification for a new error occurrence.\nThe header may include error count information if throttling has occurred.","ref":"ErrorTrackerNotifier.Email.html#send_occurrence_notification/3"},{"type":"module","title":"ErrorTrackerNotifier.UrlHelper","doc":"Helper functions for generating URLs to errors in the error tracker.","ref":"ErrorTrackerNotifier.UrlHelper.html"},{"type":"function","title":"ErrorTrackerNotifier.UrlHelper.get_base_url/0","doc":"Gets the base URL from configuration.\n\nThe client application must set this in their config:\n\n```elixir\nconfig :error_tracker_notifier,\n  # ... other error tracker config\n  base_url: \"https://your-app-domain.com\"\n```\n\nor for environment-specific URLs:\n\n```elixir\nconfig :error_tracker_notifier,\n  # ... other error tracker config\n  base_url: System.get_env(\"APP_BASE_URL\", \"https://localhost:4000\")\n```\n\nIf no base_url is configured, it will attempt to use the application's web endpoint\nmodule (e.g., MyAppWeb.Endpoint.url()) if available.","ref":"ErrorTrackerNotifier.UrlHelper.html#get_base_url/0"},{"type":"function","title":"ErrorTrackerNotifier.UrlHelper.get_error_url/1","doc":"Generates a full URL to view an error in the error tracker.","ref":"ErrorTrackerNotifier.UrlHelper.html#get_error_url/1"},{"type":"extras","title":"ErrorTrackerNotifier","doc":"# ErrorTrackerNotifier\n\nErrorTrackerNotifier is an Elixir library that adds to the amazing [ErrorTracker](https://github.com/elixir-error-tracker/error-tracker) library by sending email and/or Discord notifications for errors found by error_tracker. Note: This is a very early version and was mostly vibe-coded with some oversight so no promises!","ref":"readme.html"},{"type":"extras","title":"Installation - ErrorTrackerNotifier","doc":"The package can be installed by adding `error_tracker_notifier` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:error_tracker_notifier, \"~> 0.1.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - ErrorTrackerNotifier","doc":"Configure the library directly in your `config.exs`:\n\n```elixir\nconfig :error_tracker_notifier,\n  notification_type: :email,       # can be a single atom or a list\n  from_email: \"support@example.com\",\n  to_email: \"support@example.com\",\n  mailer: MyApp.Mailer,            # your app's Swoosh mailer module\n  base_url: \"https://your-app-domain.com\"\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Email Notifications - ErrorTrackerNotifier","doc":"Configure email notifications:\n\n```elixir\nconfig :error_tracker_notifier,\n  notification_type: :email,       # can be a single atom or a list\n  from_email: \"support@example.com\",\n  to_email: \"support@example.com\",\n  mailer: MyApp.Mailer             # your app's Swoosh mailer module\n```","ref":"readme.html#email-notifications"},{"type":"extras","title":"Discord Webhook Notifications - ErrorTrackerNotifier","doc":"Configure Discord webhook notifications:\n\n```elixir\nconfig :error_tracker_notifier,\n  notification_type: :discord,     # can be a single atom or a list\n  webhook_url: \"https://discord.com/api/webhooks/your-webhook-url\"\n```","ref":"readme.html#discord-webhook-notifications"},{"type":"extras","title":"Using Multiple Notification Types Together - ErrorTrackerNotifier","doc":"You can configure both email and Discord notifications to be sent simultaneously:\n\n```elixir\nconfig :error_tracker_notifier,\n  notification_type: [:email, :discord], # list of notification types\n  from_email: \"support@example.com\",\n  to_email: \"support@example.com\",\n  mailer: MyApp.Mailer,               # your app's Swoosh mailer module\n  webhook_url: \"https://discord.com/api/webhooks/your-webhook-url\",\n  base_url: \"https://your-app-domain.com\", # base URL for error links\n  error_tracker_path: \"/errors\",      # path to errors (default: \"/dev/errors/\")\n  throttle_seconds: 60                # time to wait between notifications for the same error\n```","ref":"readme.html#using-multiple-notification-types-together"},{"type":"extras","title":"Throttling Notifications - ErrorTrackerNotifier","doc":"To prevent alert fatigue during error storms, you can configure throttling:\n\n```elixir\nconfig :error_tracker_notifier,\n  # ... other settings\n  throttle_seconds: 10  # Only send one notification per error every 10 seconds (default)\n```\n\nWhen multiple errors of the same type occur within the throttle period, they are batched together. The next notification will include a count of how many occurrences were throttled, helping you understand the error frequency without being overwhelmed by notifications.","ref":"readme.html#throttling-notifications"},{"type":"extras","title":"URL Configuration - ErrorTrackerNotifier","doc":"You can customize the URLs generated for error links by configuring both the base URL and error path:\n\n```elixir\nconfig :error_tracker_notifier,\n  # ... other settings\n  base_url: \"https://your-app-domain.com\", \n  error_tracker_path: \"/errors\"  # default is \"/dev/errors/\"\n```\n\nThe full URL generated will be: `  / `\n\nFor example, with the above configuration, an error with ID `abc123` would have the URL: \n`https://your-app-domain.com/errors/abc123`","ref":"readme.html#url-configuration"},{"type":"extras","title":"Setup - ErrorTrackerNotifier","doc":"You have two options for setting up ErrorTrackerNotifier:","ref":"readme.html#setup"},{"type":"extras","title":"Option 1: Add to your supervision tree (recommended) - ErrorTrackerNotifier","doc":"Add ErrorTrackerNotifier to your supervision tree in `application.ex`:\n\n```elixir\ndef start(_type, _args) do\n  children = [\n    # ...other children\n    {ErrorTrackerNotifier, []}\n  ]\n\n  # Start the application supervisor with ErrorTrackerNotifier\n  Supervisor.start_link(children, strategy: :one_for_one, name: MyApp.Supervisor)\nend\n```\n\nThis starts the ErrorTrackerNotifier GenServer which handles both notification sending and throttling.","ref":"readme.html#option-1-add-to-your-supervision-tree-recommended"},{"type":"extras","title":"Option 2: Just attach telemetry handlers - ErrorTrackerNotifier","doc":"If you don't need throttling or just want to use the telemetry handlers without starting a GenServer:\n\n```elixir\n# Call this during your application startup (after ErrorTracker is initialized)\nErrorTrackerNotifier.setup_telemetry()\n```\n\nThis approach only sets up the telemetry handlers without starting the GenServer. Note that with this approach, throttling won't be available - every error will trigger a notification. \n#### Setting up a Discord Webhook\n\nTo set up a Discord webhook for error notifications:\n\n1. **Create or use an existing Discord server**\n   - You need to have the \"Manage Webhooks\" permission in the server\n\n2. **Create a channel for error notifications**\n   - It's recommended to create a dedicated channel like `#error-alerts`\n   - Go to your Discord server\n   - Click the \"+\" icon on the left sidebar to create a new channel\n   - Name it appropriately (e.g., \"error-alerts\")\n   - Set the appropriate permissions for who can see error notifications\n\n3. **Create a webhook**\n   - Right-click on the channel and select \"Edit Channel\"\n   - Select the \"Integrations\" tab\n   - Click on \"Webhooks\" and then \"New Webhook\"\n   - Give the webhook a name (e.g., \"Error Tracker\")\n   - Optionally, upload an avatar for the webhook\n   - Click \"Copy Webhook URL\" to get the URL\n   - Click \"Save\"\n\n4. **Add the webhook URL to your application config**\n   - Add the copied webhook URL to your `config.exs` as shown above\n   - Make sure to keep this URL secure, as anyone with the URL can post messages to your Discord channel\n\n5. **Test the webhook (optional)**\n   - You can test the webhook with a tool like [Postman](https://www.postman.com/) or using curl:\n   ```bash\n   curl -X POST -H \"Content-Type: application/json\" \\\n        -d '{\"content\": \"Testing error tracker webhook\"}' \\\n        https://discord.com/api/webhooks/your-webhook-url\n   ```","ref":"readme.html#option-2-just-attach-telemetry-handlers"},{"type":"extras","title":"How It Works - ErrorTrackerNotifier","doc":"ErrorTrackerNotifier listens for telemetry events from the ErrorTracker library and sends notifications when new errors occur. It handles both new errors and new occurrences of existing errors, and implements throttling to prevent notification fatigue.","ref":"readme.html#how-it-works"},{"type":"extras","title":"Email Notifications - ErrorTrackerNotifier","doc":"The notification emails include:\n- Error ID\n- Error type and message\n- Stack trace information\n- Location where the error occurred\n- Request context\n- Count of occurrences (when throttling is active)","ref":"readme.html#email-notifications"},{"type":"extras","title":"Discord Notifications - ErrorTrackerNotifier","doc":"Discord notifications provide several advantages:\n- **Real-time alerts**: Instant delivery to your team's Discord server\n- **Mobile notifications**: Get alerts on your phone via the Discord mobile app\n- **Better team visibility**: Entire teams can see and respond to errors\n- **Threaded discussions**: Team members can discuss and coordinate fixes\n- **Rich formatting**: Error details are displayed in well-formatted embeds\n- **Searchable history**: Discord keeps a searchable history of all alerts\n\nThe Discord notifications include the same information as emails, formatted as rich embeds for better readability, including error occurrence counts when throttling is active.","ref":"readme.html#discord-notifications"},{"type":"extras","title":"Dependencies - ErrorTrackerNotifier","doc":"This library depends on:\n- `error_tracker` for error tracking\n- `telemetry` for event handling\n\nFor email notifications:\n- `swoosh` for email delivery\n\nFor Discord notifications:\n- `httpoison` for making HTTP requests to Discord API\n- `jason` for JSON encoding","ref":"readme.html#dependencies"},{"type":"extras","title":"Documentation - ErrorTrackerNotifier","doc":"Documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"Environment-Specific Configuration - ErrorTrackerNotifier","doc":"ErrorTrackerNotifier is designed to work well with environment-specific configurations. If you only want to receive error notifications in your production environment, you can simply:\n\n1. Only define the configuration in `prod.exs` or `runtime.exs` (using `prod` as the environment)\n2. Leave the configuration undefined in `dev.exs` and `test.exs`\n\nWhen running in development or test environments, ErrorTrackerNotifier will automatically detect the absence of configuration and gracefully shut down without sending any notifications or logging errors.\n\n```elixir\n# Only in prod.exs or in runtime.exs with environment check\nif config_env() == :prod do\n  config :error_tracker_notifier,\n    notification_type: [:email, :discord],\n    # ... other configuration\nend\n```\n\nThis way, developers can work locally without worrying about error notifications firing in development environments.","ref":"readme.html#environment-specific-configuration"},{"type":"extras","title":"Testing with ErrorTrackerNotifier - ErrorTrackerNotifier","doc":"ErrorTrackerNotifier provides a clean way to handle testing without affecting production behavior:\n\n1. The library checks for a `:runtime_mode` configuration setting:\n   ```elixir\n   # In test_helper.exs\n   Application.put_env(:error_tracker_notifier, :runtime_mode, :test)\n   ```\n\n2. In test mode, configuration validation is bypassed, allowing tests to run without error notifications\n   \n3. You can still configure specific test behavior if needed:\n   ```elixir\n   # In test setup\n   Application.put_env(:error_tracker_notifier, :notification_type, :test)  # Special test type that doesn't send actual notifications\n   ```\n\nThis separation ensures your tests run correctly while maintaining the production behavior of gracefully shutting down when no configuration is present.","ref":"readme.html#testing-with-errortrackernotifier"},{"type":"extras","title":"Email Notifications - ErrorTrackerNotifier","doc":"","ref":"readme.html#email-notifications"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}